@@ -25,12 +25,10 @@ cd conda-recipes
 cmorversion=`echo $1 | cut -d- -f2`
 python ./prep_for_build.py -v `date +%Y.%m.%d`.${cmorversion} -b $1
 echo "Building now"
+conda build -c conda-forge -c uvcdat/label/nightly -c uvcdat --numpy=1.13 cmor
 conda build -c conda-forge -c uvcdat/label/nightly -c uvcdat --numpy=1.12 cmor
-anaconda -t $CONDA_UPLOAD_TOKEN upload -u $USER -l nightly $CONDA_BLD_PATH/$OS/$PKG_NAME-`date +%Y.%m.%d`.${cmorversion}-np112py27*_0.tar.bz2 --force
 conda build -c conda-forge -c uvcdat/label/nightly -c uvcdat --numpy=1.11 cmor
-anaconda -t $CONDA_UPLOAD_TOKEN upload -u $USER -l nightly $CONDA_BLD_PATH/$OS/$PKG_NAME-`date +%Y.%m.%d`.${cmorversion}-np111py27*_0.tar.bz2 --force
 conda build -c conda-forge  -c uvcdat/label/nightly -c uvcdat --numpy=1.10 cmor
-anaconda -t $CONDA_UPLOAD_TOKEN upload -u $USER -l nightly $CONDA_BLD_PATH/$OS/$PKG_NAME-`date +%Y.%m.%d`.${cmorversion}-np110py27*_0.tar.bz2 --force
 conda build -c conda-forge  -c uvcdat/label/nightly -c uvcdat --numpy=1.9 cmor
-anaconda -t $CONDA_UPLOAD_TOKEN upload -u $USER -l nightly $CONDA_BLD_PATH/$OS/$PKG_NAME-`date +%Y.%m.%d`.${cmorversion}-np19py27*_0.tar.bz2 --force
+anaconda -t $CONDA_UPLOAD_TOKEN upload -u $USER -l nightly $CONDA_BLD_PATH/$OS/$PKG_NAME-`date +%Y.%m.%d`.${cmorversion}-*_0.tar.bz2 --force
 
